@@ -119,6 +119,19 @@ const keyPair = new KeyPair(this, 'A-Key-Pair', {
 });
 ```
 
+### Importing public key
+
+You can create a key pair by importing the public key. Obviously, in this case the secret key won't be available in secrets manager.
+
+The public key has to be in OpenSSH format.
+
+```python
+new KeyPair(this, 'Test-Key-Pair', {
+  name: 'imported-key-pair',
+  publicKey: 'ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQCuMmbK...'
+});
+```
+
 ### Using the key pair for CloudFront signed url/cookies
 
 You can use this library for generating keys for CloudFront signed url/cookies.
@@ -180,6 +193,7 @@ class KeyPair(
         kms: typing.Optional[aws_cdk.aws_kms.Key] = None,
         kms_private_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         kms_public_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        public_key: typing.Optional[builtins.str] = None,
         public_key_format: typing.Optional["PublicKeyFormat"] = None,
         remove_key_secrets_after_days: typing.Optional[jsii.Number] = None,
         resource_prefix: typing.Optional[builtins.str] = None,
@@ -202,6 +216,7 @@ class KeyPair(
         :param kms: The KMS key used to encrypt the Secrets Manager secrets with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. Default: - ``alias/aws/secretsmanager``
         :param kms_private_key: The KMS key to use to encrypt the private key with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. If no value is provided, the property ``kms`` will be used instead. Default: - ``this.kms``
         :param kms_public_key: The KMS key to use to encrypt the public key with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. If no value is provided, the property ``kms`` will be used instead. Default: - ``this.kms``
+        :param public_key: Import a public key instead of creating it. If no public key is provided, a new key pair will be created.
         :param public_key_format: Format for public key. Relevant only if the public key is stored and/or exposed. Default: - OPENSSH
         :param remove_key_secrets_after_days: When the resource is destroyed, after how many days the private and public key in the AWS Secrets Manager should be deleted. Valid values are 0 and 7 to 30 Default: 0
         :param resource_prefix: A prefix for all resource names. By default all resources are prefixed with the stack name to avoid collisions with other stacks. This might cause problems when you work with long stack names and can be overridden through this parameter. Default: Name of the stack
@@ -219,6 +234,7 @@ class KeyPair(
             kms=kms,
             kms_private_key=kms_private_key,
             kms_public_key=kms_public_key,
+            public_key=public_key,
             public_key_format=public_key_format,
             remove_key_secrets_after_days=remove_key_secrets_after_days,
             resource_prefix=resource_prefix,
@@ -319,6 +335,7 @@ class KeyPair(
         "kms": "kms",
         "kms_private_key": "kmsPrivateKey",
         "kms_public_key": "kmsPublicKey",
+        "public_key": "publicKey",
         "public_key_format": "publicKeyFormat",
         "remove_key_secrets_after_days": "removeKeySecretsAfterDays",
         "resource_prefix": "resourcePrefix",
@@ -340,6 +357,7 @@ class KeyPairProps(aws_cdk.ResourceProps):
         kms: typing.Optional[aws_cdk.aws_kms.Key] = None,
         kms_private_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         kms_public_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        public_key: typing.Optional[builtins.str] = None,
         public_key_format: typing.Optional["PublicKeyFormat"] = None,
         remove_key_secrets_after_days: typing.Optional[jsii.Number] = None,
         resource_prefix: typing.Optional[builtins.str] = None,
@@ -358,6 +376,7 @@ class KeyPairProps(aws_cdk.ResourceProps):
         :param kms: The KMS key used to encrypt the Secrets Manager secrets with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. Default: - ``alias/aws/secretsmanager``
         :param kms_private_key: The KMS key to use to encrypt the private key with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. If no value is provided, the property ``kms`` will be used instead. Default: - ``this.kms``
         :param kms_public_key: The KMS key to use to encrypt the public key with. This needs to be a key created in the same stack. You cannot use a key imported via ARN, because the keys access policy will need to be modified. If no value is provided, the property ``kms`` will be used instead. Default: - ``this.kms``
+        :param public_key: Import a public key instead of creating it. If no public key is provided, a new key pair will be created.
         :param public_key_format: Format for public key. Relevant only if the public key is stored and/or exposed. Default: - OPENSSH
         :param remove_key_secrets_after_days: When the resource is destroyed, after how many days the private and public key in the AWS Secrets Manager should be deleted. Valid values are 0 and 7 to 30 Default: 0
         :param resource_prefix: A prefix for all resource names. By default all resources are prefixed with the stack name to avoid collisions with other stacks. This might cause problems when you work with long stack names and can be overridden through this parameter. Default: Name of the stack
@@ -385,6 +404,8 @@ class KeyPairProps(aws_cdk.ResourceProps):
             self._values["kms_private_key"] = kms_private_key
         if kms_public_key is not None:
             self._values["kms_public_key"] = kms_public_key
+        if public_key is not None:
+            self._values["public_key"] = public_key
         if public_key_format is not None:
             self._values["public_key_format"] = public_key_format
         if remove_key_secrets_after_days is not None:
@@ -510,6 +531,15 @@ class KeyPairProps(aws_cdk.ResourceProps):
         result = self._values.get("kms_public_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
 
+    @builtins.property
+    def public_key(self) -> typing.Optional[builtins.str]:
+        '''Import a public key instead of creating it.
+
+        If no public key is provided, a new key pair will be created.
+        '''
+        result = self._values.get("public_key")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def public_key_format(self) -> typing.Optional["PublicKeyFormat"]:
         '''Format for public key.
